# Internet NLP

Allowing NLPs and NLIs to connect to the internet.

This is an customizable (comming soon) package to allow for internet related NLP task to be done easily.

If you are going to use this please cite it as below:
